@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 from mopidy import config, ext
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 
 class Extension(ext.Extension):
@@ -20,9 +20,12 @@ class Extension(ext.Extension):
         schema = super(Extension, self).get_config_schema()
         schema['display_name'] = config.String()
         schema['base_url'] = config.String()
-        schema['top_tags_count'] = config.Integer(minimum=1)
-        schema['podcasts_count'] = config.Integer(minimum=1)
-        schema['timeout'] = config.Integer(optional=True)
+        schema['tags'] = config.Integer(minimum=1)
+
+        # config values no longer needed
+        schema['top_tags_count'] = config.Deprecated()
+        schema['podcasts_count'] = config.Deprecated()
+        schema['timeout'] = config.Deprecated()
         return schema
 
     def setup(self, registry):
